#!perl
use 5.008003;
use strict;
use warnings;
use Test::More;

plan tests => 123;

BEGIN {
    use_ok( 'Google::Cloud::Compute::V1::AcceleratorTypesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::AddressesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::AdviceClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::AutoscalersClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::BackendBucketsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::BackendServicesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::CrossSiteNetworksClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::DiskTypesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::DisksClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ExternalVpnGatewaysClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::FirewallPoliciesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::FirewallsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ForwardingRulesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::FutureReservationsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::GlobalAddressesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::GlobalForwardingRulesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::GlobalNetworkEndpointGroupsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::GlobalOperationsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::GlobalOrganizationOperationsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::GlobalPublicDelegatedPrefixesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::GlobalVmExtensionPoliciesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::HealthChecksClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ImageFamilyViewsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ImagesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequestsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InstanceGroupManagersClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InstanceGroupsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InstanceSettingsServiceClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InstanceTemplatesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InstancesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InstantSnapshotGroupsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InstantSnapshotsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InterconnectAttachmentGroupsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InterconnectAttachmentsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InterconnectGroupsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InterconnectLocationsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InterconnectRemoteLocationsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::InterconnectsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::LicenseCodesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::LicensesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::MachineImagesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::MachineTypesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::NetworkAttachmentsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::NetworkEndpointGroupsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::NetworkFirewallPoliciesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::NetworkProfilesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::NetworksClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::NodeGroupsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::NodeTemplatesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::NodeTypesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::OrganizationSecurityPoliciesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::PacketMirroringsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::PreviewFeaturesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ProjectsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::PublicAdvertisedPrefixesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::PublicDelegatedPrefixesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionAutoscalersClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionBackendBucketsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionBackendServicesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionCommitmentsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionCompositeHealthChecksClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionDiskTypesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionDisksClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionHealthAggregationPoliciesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionHealthCheckServicesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionHealthChecksClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionHealthSourcesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionInstanceGroupManagerResizeRequestsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionInstanceGroupManagersClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionInstanceGroupsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionInstanceTemplatesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionInstancesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionInstantSnapshotGroupsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionInstantSnapshotsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionNetworkEndpointGroupsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionNetworkFirewallPoliciesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionNotificationEndpointsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionOperationsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionSecurityPoliciesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionSnapshotSettingsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionSnapshotsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionSslCertificatesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionSslPoliciesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionTargetHttpProxiesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionTargetHttpsProxiesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionTargetTcpProxiesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionUrlMapsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionZonesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RegionsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ReservationBlocksClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ReservationSlotsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ReservationSubBlocksClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ReservationsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ResourcePoliciesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RolloutPlansClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RolloutsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RoutersClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::RoutesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::SecurityPoliciesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ServiceAttachmentsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::SnapshotSettingsServiceClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::SnapshotsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::SslCertificatesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::SslPoliciesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::StoragePoolTypesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::StoragePoolsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::SubnetworksClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::TargetGrpcProxiesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::TargetHttpProxiesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::TargetHttpsProxiesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::TargetInstancesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::TargetPoolsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::TargetSslProxiesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::TargetTcpProxiesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::TargetVpnGatewaysClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::UrlMapsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::VpnGatewaysClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::VpnTunnelsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::WireGroupsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ZoneOperationsClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ZoneVmExtensionPoliciesClient' ) || print "Bail out!\n";
    use_ok( 'Google::Cloud::Compute::V1::ZonesClient' ) || print "Bail out!\n";
}

diag( "Testing Google::Cloud::Compute::V1::AcceleratorTypesClient $Google::Cloud::Compute::V1::AcceleratorTypesClient::VERSION, Perl $], $^X" );
